from pypigeon.pigeon_core.api.group import group_create_group
from pypigeon.pigeon_core.api.group import group_get_groups
from pypigeon.pigeon_core.api.group import group_update_group
from pypigeon.pigeon_core.models import GroupCreateGroupBody
from pypigeon.pigeon_core.models import GroupUpdateGroupBody
from pypigeon.pigeon_core.models import VisibilityLevel

from .base_commands import BaseCommands


class GroupsCommands(BaseCommands):
    """Operations on groups"""

    @BaseCommands._with_arg("name")
    @BaseCommands._with_arg("--public", action="store_true")
    def new(self) -> None:
        """Create a new group."""
        rv = group_create_group.sync(
            body=GroupCreateGroupBody(
                name=self.args.name,
                visibility_level=(
                    VisibilityLevel.PUBLIC
                    if self.args.public
                    else VisibilityLevel.UNLISTED
                ),
            ),
            client=self.core,
        )

        self._output(rv.to_dict())

    def list(self) -> None:
        """List all visible groups."""
        rv = group_get_groups.sync(client=self.core)

        self._output(rv.to_dict())

    @BaseCommands._with_arg("--name")
    @BaseCommands._with_arg("--make-public", action="store_true")
    @BaseCommands._with_arg("--make-unlisted", action="store_true")
    @BaseCommands._with_arg("group_id")
    def update(self) -> None:
        """Update a group."""
        update = GroupUpdateGroupBody()
        if self.args.name:
            update.name = self.args.name
        if self.args.make_public:
            update.visibility_level = VisibilityLevel.PUBLIC
        if self.args.make_unlisted:
            update.visibility_level = VisibilityLevel.UNLISTED
        group_update_group.sync(
            group_id=self.args.group_id, body=update, client=self.core
        )



from typing import Any
from typing import Dict
from typing import List
from typing import Type
from typing import TypeVar
from typing import Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET
from ..types import Unset


T = TypeVar("T", bound="ServerError")


@_attrs_define
class ServerError:
    """ServerError model

    Attributes:
        detail (Union[Unset, str]):
        error (Union[Unset, str]):
    """

    detail: Union[Unset, str] = UNSET
    error: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        """Convert to a dict"""
        detail = self.detail
        error = self.error

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if detail is not UNSET:
            field_dict["detail"] = detail
        if error is not UNSET:
            field_dict["error"] = error

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        """Create an instance of :py:class:`ServerError` from a dict"""
        d = src_dict.copy()
        detail = d.pop("detail", UNSET)

        error = d.pop("error", UNSET)

        server_error = cls(
            detail=detail,
            error=error,
        )

        server_error.additional_properties = d
        return server_error

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any
from typing import Dict
from typing import Type
from typing import TypeVar

from attrs import define as _attrs_define


T = TypeVar("T", bound="AccountCreateAccountBody")


@_attrs_define
class AccountCreateAccountBody:
    """AccountCreateAccountBody model

    Attributes:
        name (str):
    """

    name: str

    def to_dict(self) -> Dict[str, Any]:
        """Convert to a dict"""
        name = self.name

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "name": name,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        """Create an instance of :py:class:`AccountCreateAccountBody` from a dict"""
        d = src_dict.copy()
        name = d.pop("name")

        account_create_account_body = cls(
            name=name,
        )

        return account_create_account_body



from enum import Enum


class ParserOptionsAdditionalPropertyType(str, Enum):
    BOOLEAN = "boolean"
    INTEGER = "integer"
    NUMBER = "number"
    STRING = "string"

    def __str__(self) -> str:
        return str(self.value)
